/*--------------------------------------------------------------------------------------------------
Descriptive analysis

	Outline:
	
	1. descriptive statistics at the markaz year level
		- Table 1
		- Table B1
		
	2. descriptive statistics at the unit by month level
		- Table A1
		
	3. measures of variation
		- Table 2

	4.  descriptive statistics district level
		- Figure 3
	
	5. distribution of number of times flagged by school
		- Figure 4
		
	6. evolution of outcomes in relative time
		- Figure 5
		
	7. data validation: evolution of outcomes by state
		- Figure A1

	8. data validation: distribution and errors in reporting
		- Figure A3

--------------------------------------------------------------------------------------------------*/
*
*
*
*
*
*---------------------------------------------------------------------------------------------------
**# 1. descriptive statistics at the markaz year level #

*number of times flagged
*number of times in the threshold
*number of times flagged while in the threshold

use "$analysis/processed/cc_mar_year_data.dta", clear

*label variables
if(1){
	
* outcomes 
label var mar_tpres "Teacher presence"
label var mar_satt "Student attendance"
label var mar_fac "Functional facilities"
label var mar_math "Math score"
label var mar_eng "English score"
label var mar_urdu "Urdu score"

* flagging variables
label var flagtpres  "Teacher presence - \# times flagged"
label var flagsatt "Student attendance - \# times flagged"
label var flagfac  "Functional facilities - \# times flagged"
label var flagmath  "Match score - \# times flagged"
label var flageng  "English score - \# times flagged"
label var flagurdu  "Urdu score - \# times flagged"

* flagging in the threshold variables
label var flagtpres_thres  "Teacher presence - \# times flagged close to the threshold"
label var flagsatt_thres "Student attendance - \# times flagged close to the threshold"
label var flagfac_thres  "Functional facilities - \# times flagged close to the threshold"
label var flagmath_thres  "Match score - \# times flagged close to the threshold"
label var flageng_thres  "English score - \# times flagged close to the threshold"
label var flagurdu_thres  "Urdu score - \# times flagged close to the threshold"

* times close to the threshold variables
label var threstpres  "Teacher presence - \# times close to the threshold"
label var thressatt "Student attendance - \# times close to the threshold"
label var thresfac  "Functional facilities - \# times close to the threshold"
label var thresmath  "Match score - \# times close to the threshold"
label var threseng  "English score - \# times close to the threshold"
label var thresurdu  "Urdu score - \# times close to the threshold"

}

*panel A schooling outcomes
local vars tpres satt fac math eng urdu
foreach v of local vars{

eststo mschool`v': estpost tabstat mar_`v' if mar_`v' != ., statistics(mean sd min max count) columns(statistics)

}

*panel B times flagged
local vars tpres satt fac math eng urdu
foreach v of local vars{

eststo mschool_flag`v': estpost tabstat flag`v' if mar_`v' != ., statistics(mean sd min max count) columns(statistics)

}

**** Table 1
if(1){

*teacher presence
esttab mschooltpres using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead(\begin{tabular}{lccccc} \toprule ///
	    "\multicolumn{1}{l}{\textbf{Panel A: Schooling outcomes (0-100)}} & \multicolumn{1}{c}{Mean} & \multicolumn{1}{c}{Std. Dev.} & \multicolumn{1}{c}{Min.} & \multicolumn{1}{c}{Max.} & \multicolumn{1}{c}{Obs.}  \\") ///
		posthead("\cmidrule{2-6} \addlinespace[0.5em]") ///
		postfoot("") ///
		replace unstack noobs nomtitle nonumber label booktabs compress
		
*student attendance
esttab mschoolsatt using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
*functional facilities
esttab mschoolfac using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
*math
esttab mschoolmath using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

*english
esttab mschooleng using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

*urdu		
esttab mschoolurdu using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("\midrule") ///
		append unstack noobs nomtitle nonumber label booktabs compress
	
* second part of the table
*------------------------------------------
	
*teacher presence
esttab mschool_flagtpres using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("\multicolumn{1}{l}{\textbf{Panel B: Number of times flagged}} & \multicolumn{1}{c}{Mean} & \multicolumn{1}{c}{Std. Dev.} & \multicolumn{1}{c}{Min.} & \multicolumn{1}{c}{Max.} & \multicolumn{1}{c}{Obs.}  \\") ///
		posthead("\cmidrule{2-6} \addlinespace[0.5em]") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress
	
*student attendance
esttab mschool_flagsatt using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
*functional facilities
esttab mschool_flagfac using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
*math
esttab mschool_flagmath using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

*english
esttab mschool_flageng using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

*urdu
esttab mschool_flagurdu using "$analysis/tables/descriptive/Table1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("\bottomrule \end{tabular}") ///
		append unstack noobs nomtitle nonumber label booktabs compress
	
	
}

* table flagging in threshold measures
local vars tpres satt fac math eng urdu
foreach v of local vars{
eststo mschool`v': estpost tabstat thres`v' flag`v'_thres if mar_`v' != ., statistics(mean sd min max count) columns(statistics)
}

**** Table B1
if(1){

*teacher presence
esttab mschooltpres using "$analysis/tables/descriptive/TableB1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead(\begin{tabular}{lccccc} \toprule ///
	    " \multicolumn{1}{l}{\textbf{Schooling outcome - flagging variable}} & \multicolumn{1}{c}{Mean} & \multicolumn{1}{c}{Std. Dev.} & \multicolumn{1}{c}{Min.} & \multicolumn{1}{c}{Max.} & \multicolumn{1}{c}{Obs.}  \\") ///
		posthead("\cmidrule{2-6} \addlinespace[0.5em]") ///
		postfoot(\midrule) ///
		replace unstack noobs nomtitle nonumber label booktabs compress
		
*student attendance
esttab mschoolsatt using "$analysis/tables/descriptive/TableB1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot(\midrule) ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
*functional facilities
esttab mschoolfac using "$analysis/tables/descriptive/TableB1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot(\midrule) ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
*math
esttab mschoolmath using "$analysis/tables/descriptive/TableB1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot(\midrule) ///
		append unstack noobs nomtitle nonumber label booktabs compress

*english
esttab mschooleng using "$analysis/tables/descriptive/TableB1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot(\midrule) ///
		append unstack noobs nomtitle nonumber label booktabs compress

*urdu		
esttab mschoolurdu using "$analysis/tables/descriptive/TableB1.tex", ///
		cells("mean(fmt(%4.3fc) label(Mean)) sd(fmt(%4.3fc) label(Std. Dev.)) min(fmt(%4.0fc) label(Min)) max(fmt(%4.0fc) label(Max)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("\bottomrule \end{tabular}") ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
}

*---------------------------------------------------------------------------------------------------
**# 2. descriptive statistics at the unit by month level #

***** Table A1
if(1){
	
*Panel A
if(1){
	
// data arrangement for table

* we use the balanced dataset
use "$analysis/processed/cc_datapacks.dta", clear

*create variable for number of schools and proportion not in wing 3
sort mar date_treat emis
gen random = runiform()
sort mar date_treat emis random
bys mar date_treat emis (random): gen ord = _n
keep if ord == 1
drop random ord

gen temp = 1
bys mar date_treat: egen numschools = sum(temp)
drop temp
gen temp = 1 if wing != 3
bys mar date_treat: egen propnowingchools = sum(temp)
drop temp
gen propschools = (propnowingchools/numschools)*100

preserve
*drop if wing == 3
collapse (max) propschools numschools, ///
		by(mar date_treat treat_tpres_ treat_satt_ treat_fac_ treat_math_  ///
		   treat_eng_ treat_urdu_)
		   
*just a trick ...
gen treat = 1
	
//general

label var numschools "Number of schools"
label var propschools "Proportion elementary"
eststo mschool: estpost tabstat numschools propschools if treat== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mschool mschool using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		///collabels(none) /// no label for columns
		prehead(\begin{tabular}{lcccccccc} \toprule ///
	    "\multicolumn{8}{l}{\textbf{Panel A: Markaz-level variables}} \\") ///
		posthead("\cmidrule{2-9} \addlinespace[0.5em]") ///
		postfoot(\midrule) ///
		replace unstack noobs nomtitle nonumber label booktabs compress
		
restore
	
preserve

drop if wing == 3
collapse (mean) mar_tpres mar_satt mar_fac ///
			                                 mar_math mar_eng mar_urdu, ///
		by(mar date_treat treat_tpres_ treat_satt_ treat_fac_ treat_math_  ///
		   treat_eng_ treat_urdu_)
	
//outcomes
label var mar_tpres "Teacher presence"
label var mar_satt "Student attendance"
label var mar_fac "Functional facilities"
label var mar_math "Math score"
label var mar_eng "English score"
label var mar_urdu "Urdu score"

eststo mflag: estpost tabstat mar_tpres if treat_tpres_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat mar_tpres if treat_tpres_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("Outcomes (0-100) & \multicolumn{4}{c}{\textbf{No flag}} & \multicolumn{4}{c}{\textbf{Flag}} \\") ///
		posthead("\cmidrule{2-5} \cmidrule{6-9} \addlinespace[0.5em]") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo mflag: estpost tabstat mar_satt if treat_satt_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat mar_satt if treat_satt_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo mflag: estpost tabstat mar_fac if treat_fac_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat mar_fac if treat_fac_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo mflag: estpost tabstat mar_math if treat_math_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat mar_math if treat_math_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo mflag: estpost tabstat mar_eng if treat_eng_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat mar_eng if treat_eng_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
eststo mflag: estpost tabstat mar_urdu if treat_urdu_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat mar_urdu if treat_urdu_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot(\midrule) ///
		append unstack noobs nomtitle nonumber label booktabs compress

restore

}

*Panel B
if(1){

* we use the balanced dataset
use "$analysis/processed/cc_datapacks.dta", clear
drop if wing == 3

//general

label var totalteachers "Number of teachers"
label var students "Number of students"
eststo mschool: estpost tabstat totalteachers students, statistics(mean p50 sd count) columns(statistics)

esttab mschool mschool using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		///collabels(none) /// no label for columns
		prehead("\multicolumn{8}{l}{\textbf{Panel B: School-level variables}} \\") ///
		posthead("\cmidrule{2-9} \addlinespace[0.5em]") ///
		postfoot(\midrule) ///
		append unstack noobs nomtitle nonumber label booktabs compress

//outcomes

label var tpres "Teacher presence"
label var satt "Student attendance"
label var fac "Functional facilities"
label var math "Math score"
label var eng "English score"
label var urdu "Urdu score"

eststo mflag: estpost tabstat tpres if treat_tpres_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat tpres if treat_tpres_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("Outcomes (0-100) & \multicolumn{4}{c}{\textbf{No flag}} & \multicolumn{4}{c}{\textbf{Flag}} \\") ///
		posthead("\cmidrule{2-5} \cmidrule{6-9} \addlinespace[0.5em]") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo mflag: estpost tabstat satt if treat_satt_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat satt if treat_satt_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo mflag: estpost tabstat fac if treat_fac_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat fac if treat_fac_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo mflag: estpost tabstat math if treat_math_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat math if treat_math_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo mflag: estpost tabstat eng if treat_eng_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat eng if treat_eng_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
eststo mflag: estpost tabstat urdu if treat_urdu_== 0 , statistics(mean p50 sd count) columns(statistics)
eststo mnoflag: estpost tabstat urdu if treat_urdu_== 1 , statistics(mean p50 sd count) columns(statistics)

esttab mflag mnoflag using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot(\midrule) ///
		append unstack noobs nomtitle nonumber label booktabs compress

}

*Panel C
if(1){
	
use "$data/ranking", replace
	
// sumstats of overall score
preserve
 
*ranking variable
gen D = (rank_position < 6) 
replace D = 2 if rank_position > 31

label var overallscore "Overall score"

* drop outside the extremes
drop if D == 0
eststo mtop: estpost tabstat overallscore if D == 2, statistics(mean p50 sd count) columns(statistics)
eststo mbottom: estpost tabstat overallscore if D == 1, statistics(mean p50 sd count) columns(statistics)

esttab mtop mbottom using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		///collabels(none) /// no label for columns
		prehead("\multicolumn{8}{l}{\textbf{Panel C: District-level variables}} \\") ///
		posthead("\cmidrule{2-9} \addlinespace[0.5em]" ///
			"Outcomes (0-100) & \multicolumn{4}{c}{\textbf{Top 5}} & \multicolumn{4}{c}{\textbf{Bottom 5}} \\ " ///
			"\cmidrule{2-5} \cmidrule{6-9} \addlinespace[0.5em]") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

restore 

// sumstats of change of positions
preserve 

*ranking variable
gen D = (rank_position < 6) 
replace D = 2 if rank_position > 31
bys district (date_treat): gen old_D = D[_n-1]
gen new_top = (old_D != D & D == 1)
replace new_top = new_top * 100
gen new_bottom = (old_D != D & D == 2)
replace new_bottom = new_bottom * 100

label var new_bottom "New position"
label var new_top "New position"
rename new_top new
eststo mtop: estpost tabstat new, statistics(mean p50 sd count) columns(statistics)
rename new new_top
rename new_bottom new
eststo mbottom: estpost tabstat new, statistics(mean p50 sd count) columns(statistics)
rename new new_bottom

esttab mtop mbottom using "$analysis/tables/descriptive/TableA1.tex", ///
		cells("mean(fmt(%11.2gc) label(Mean)) p50(fmt(%11.2gc) label(Median)) sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		varlabel(new "New position") ///
		prehead("") ///
		posthead("") ///
		postfoot("\bottomrule \end{tabular}") ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
restore 

}

}

*---------------------------------------------------------------------------------------------------
**# 3. measures of variation #

***** Table 2
if(1){
	
use "$analysis/processed/cc_datapacks.dta", clear
keep if wing != 3

*collapse all schools time as an average of each variable: then at the school level
collapse (mean) tpres satt fac math eng urdu, by(emis)

*create for each category the quintiles
local vars tpres satt fac math eng urdu
foreach v of local vars{
	xtile quint_`v' = `v', n(5)	
	
} // end loop

label var tpres "Teacher presence"
label var satt "Student attendance"
label var fac "Functional facilities"
label var math "Math score"
label var eng "English score"
label var urdu "Urdu score"

*estimate variation table for each variable
/*as before we create the paper table based on this tables that require further formating*/

eststo m1: estpost tabstat tpres if quint_tpres == 1, statistics(sd) columns(statistics)
eststo m2: estpost tabstat tpres if quint_tpres == 2, statistics(sd) columns(statistics)
eststo m3: estpost tabstat tpres if quint_tpres == 3, statistics(sd) columns(statistics)
eststo m4: estpost tabstat tpres if quint_tpres == 4, statistics(sd) columns(statistics)
eststo m5: estpost tabstat tpres if quint_tpres == 5, statistics(sd) columns(statistics)
eststo mall: estpost tabstat tpres, statistics(sd count) columns(statistics)

esttab m1 m2 m3 m4 m5 mall using "$analysis/tables/descriptive/Table2.tex", ///
		cells("sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs.))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead(\begin{tabular}{lccccccccccccc} \toprule ///
	    "\multicolumn{13}{l}{\textbf{School-level variation (sd) by quintiles of performance}} \\" ///
		"Outcome (0-100) & Q1 & & Q2 & & Q3 & & Q4 & & Q5 & & All & Obs. \\" ///
		) ///
		posthead("\cmidrule{2-13} \addlinespace[0.5em]") ///
		postfoot("") ///
		replace unstack noobs nomtitle nonumber label booktabs compress

eststo m1: estpost tabstat satt if quint_satt == 1, statistics(sd) columns(statistics)
eststo m2: estpost tabstat satt if quint_satt == 2, statistics(sd) columns(statistics)
eststo m3: estpost tabstat satt if quint_satt == 3, statistics(sd) columns(statistics)
eststo m4: estpost tabstat satt if quint_satt == 4, statistics(sd) columns(statistics)
eststo m5: estpost tabstat satt if quint_satt == 5, statistics(sd) columns(statistics)
eststo mall: estpost tabstat satt, statistics(sd count) columns(statistics)

esttab m1 m2 m3 m4 m5 mall using "$analysis/tables/descriptive/Table2.tex", ///
		cells("sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs.))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo m1: estpost tabstat fac if quint_fac == 1, statistics(sd) columns(statistics)
eststo m2: estpost tabstat fac if quint_fac == 2, statistics(sd) columns(statistics)
eststo m3: estpost tabstat fac if quint_fac == 3, statistics(sd) columns(statistics)
eststo m4: estpost tabstat fac if quint_fac == 4, statistics(sd) columns(statistics)
eststo m5: estpost tabstat fac if quint_fac == 5, statistics(sd) columns(statistics)
eststo mall: estpost tabstat fac, statistics(sd count) columns(statistics)

esttab m1 m2 m3 m4 m5 mall using "$analysis/tables/descriptive/Table2.tex", ///
		cells("sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs.))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo m1: estpost tabstat math if quint_math == 1, statistics(sd) columns(statistics)
eststo m2: estpost tabstat math if quint_math == 2, statistics(sd) columns(statistics)
eststo m3: estpost tabstat math if quint_math == 3, statistics(sd) columns(statistics)
eststo m4: estpost tabstat math if quint_math == 4, statistics(sd) columns(statistics)
eststo m5: estpost tabstat math if quint_math == 5, statistics(sd) columns(statistics)
eststo mall: estpost tabstat math, statistics(sd count) columns(statistics)

esttab m1 m2 m3 m4 m5 mall using "$analysis/tables/descriptive/Table2.tex", ///
		cells("sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs.))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress

eststo m1: estpost tabstat eng if quint_eng == 1, statistics(sd) columns(statistics)
eststo m2: estpost tabstat eng if quint_eng == 2, statistics(sd) columns(statistics)
eststo m3: estpost tabstat eng if quint_eng == 3, statistics(sd) columns(statistics)
eststo m4: estpost tabstat eng if quint_eng == 4, statistics(sd) columns(statistics)
eststo m5: estpost tabstat eng if quint_eng == 5, statistics(sd) columns(statistics)
eststo mall: estpost tabstat eng, statistics(sd count) columns(statistics)

esttab m1 m2 m3 m4 m5 mall using "$analysis/tables/descriptive/Table2.tex", ///
		cells("sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs.))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("") ///
		append unstack noobs nomtitle nonumber label booktabs compress
		
eststo m1: estpost tabstat urdu if quint_urdu == 1, statistics(sd) columns(statistics)
eststo m2: estpost tabstat urdu if quint_urdu == 2, statistics(sd) columns(statistics)
eststo m3: estpost tabstat urdu if quint_urdu == 3, statistics(sd) columns(statistics)
eststo m4: estpost tabstat urdu if quint_urdu == 4, statistics(sd) columns(statistics)
eststo m5: estpost tabstat urdu if quint_urdu == 5, statistics(sd) columns(statistics)
eststo mall: estpost tabstat urdu, statistics(sd count) columns(statistics)

esttab m1 m2 m3 m4 m5 mall using "$analysis/tables/descriptive/Table2.tex", ///
		cells("sd(fmt(%11.2gc) label(Std. Dev.)) count(fmt(%11.2gc) label(Obs.))") ///
		mlabels(none) /// no label for models
		collabels(none) /// no label for columns
		prehead("") ///
		posthead("") ///
		postfoot("\bottomrule \end{tabular}") ///
		append unstack noobs nomtitle nonumber label booktabs compress


}

*---------------------------------------------------------------------------------------------------
**# 4. descriptive statistics district level #

use "$data/ranking", replace

***** Figure 3
if(1){
	
preserve 

	*estimate quartiles
gen cuart = .
levelsof date_treat
	foreach d in `r(levels)'{
		xtile x = overallscore if date_treat == `d', nq(5)
		replace cuart = x if date_treat == `d'
		drop x
	}
	
sort district cuart
gen x = cuart
bys district: egen total = sum(overall)
bys date_treat (total): gen id = _n

	*panelview	
colorpalette "red" "orange" "yellow" "lime" "green", nograph

panelview cuart x if date_treat < tm(2015m3), i(id) t(date_treat) type(treat) ///
	ytitle("District performance position") xtitle("Quarterly meetings") graphregion(color(white)) ///
	ylabel(1 "Worst performer" 36 "Best performer",  labsize(small)) ///
	xlabel(1 "2011m12" 2 "2012m3" 3 "2012m5" 4 "2012m9" 5 "2012m12" 6 "2013m3" 7 "2013m6" ///
		8 "2013m9" 9 "2013m12" 10 "2014m3" 11 "2014m6" 12 "2014m9" 13 "2014m12", labsize(small)) ///
	mycolor(`r(p)') ///
	legend(order(1 "1st quint" 2 "2nd quint" 3 "3rd quint" 4 "4th quint" 5 "5th quint") size(small) col(2) pos(6)) 
	
graph export "$analysis/figures/descriptive/Figure3.pdf", replace

restore

}

*---------------------------------------------------------------------------------------------------
**# 5. distribution of number of times flagged by school #

***** Figure 4
if(1){
	
use "$analysis/processed/cc_mar_emis_year_data.dta", clear

collapse (sum) flagtpres flagsatt flagfac flagmath flageng flagurdu ///
			   flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres, ///
			   by(emis)
			   
egen totalflag = rowtotal(flagtpres flagsatt flagfac flagmath flageng flagurdu), m
egen totalflag_thres = rowtotal(flagtpres_thres flagsatt_thres flagfac_thres flagmath_thres flageng_thres flagurdu_thres), m


twoway (hist totalflag if totalflag < 100, freq discrete col(blue%30)) ///
	   (hist totalflag_thres, freq discrete col(red%30)), ///
	legend(order(1 "Times flagged" 2 "Times flagged close to threshold") col(2) size(large) region(lstyle(none)) pos(6)) ///
	ytitle("Frequency", size(large)) xtitle("Total number of times flagged (any outcome)", size(large)) ylabel(0(250)2500, nogrid) xlabel(, nogrid)

graph export "$analysis/figures/descriptive/Figure4.pdf", replace

}

*---------------------------------------------------------------------------------------------------
**# 6. evolution of outcomes in relative time #

***** Figure 5 
global treatments tpres satt fac math eng urdu // Panel A, B, C, D, E, F
foreach v of global treatments{
	
/*we use stacked data with 5 post periods after the punishment
note that we have to iterate over each variable as we created different datasets for each one
*/

use "$analysis/processed/stacked/cc_stackdata5_`v'.dta", clear

/*functional facilities evolution is "weird", and each variable has its characteristics, 
we plot them separately*/

	* evolution full data
	preserve
	collapse (mean) mar_`v' [aw = avg_totalreportedteachers_mar], ///
		by(flagged relativetime)
	gen full = 1
	tempfile full
	save `full'
	restore 
		
	* evolution rd data
	preserve
	keep if rd1 == 1
	collapse (mean) mar_`v' [aw = avg_totalreportedteachers_mar], ///
		by(flagged relativetime)
			
	gen full = 0
	tempfile rd
	save `rd'
	restore 

	
	* merge both to graph
	preserve
	use `full', clear
	append using `rd'
	
	//define parameters
	
	if("`v'" == "fac"){
		
		local ymin = 80
		local bet = 2		
		local height = 83
		
	}
	else if("`v'" == "tpres" | "`v'" == "satt"){
		
		local ymin = 80
		local bet = 2
		local height = 96.5
		
	}
	else{
		
		local ymin = 60
		local bet = 5		
		local height = 93.5
		
	}


		
	* graph everything
	twoway (line mar_`v' relativetime if flagged == 1 & full == 1, ///
			lcol("navy") lpattern(solid) lwidth(0.5)) ///
		(line mar_`v' relativetime if flagged == 0 & full == 1, ///
			lcol("navy") lpattern(dash) lwidth(0.5)) ///
		(line mar_`v' relativetime if flagged == 1 & full == 0, ///
			lcol("cranberry") lpattern(solid) lwidth(0.5)) ///
		(line mar_`v' relativetime if flagged == 0 & full == 0, ///
			lcol("cranberry") lpattern(dash) lwidth(0.5)) ///
		(scatteri 100 -0.5 100 0.49, recast(area) lwidth(none) col(gs14%50)) ///
		(scatteri 100 0.5 100 1.49, recast(area) lwidth(none) col(gs12%50)) ///
		(scatteri 100 1.5 100 6.49, recast(area) lwidth(none) col(gs8%50)), ///
		text(`height' 0 "{bf: Flag} " `height' 1 "{bf:Punish}" `height' 4 "{bf:After}" "{bf:flag}", size(large) ///
			orient(vertical) placement(c)) ///
		graphregion(color(white)) xtitle("Period", size(large)) ytitle("Average outcome", size(vlarge)) ///
		xlabel(-4(1)6, nogrid) yscale(r(`ymin' 100)) ylabel(`ymin'(`bet')100, nogrid) ///
		legend(order(1 "Flag (Full)" 2 "No flag (Full)" 3 "Flag (Threshold)" 4 "No flag (Threshold)") size(vlarge) region(lstyle(none)) pos(6) cols(2))
			
	graph export "$analysis/figures/descriptive/Figure5_`v'.pdf", replace
	restore
	
	}	

*---------------------------------------------------------------------------------------------------
**# 7. data validation: evolution of outcomes by district #

***** Figure A1
/*we use data of external sources (ASER Pakistan) to explore the evolution of 
outcomes*/

if(1){
	
use "$data/asertime", clear
	
* figures

twoway (connect tpres year if province == "Punjab", lwidth(thick)) ///
	(connect tpres year if province == "Sindh", lcol(navy%70) mcol(navy%70) lwidth(thin) msize(small) msymbol(triangle)) ///
	(connect tpres year if province == "Balochistan", lcol(blue%70) mcol(blue%70) lwidth(thin) msize(small) msymbol(diamond)) ///
	(connect tpres year if province == "Gilgit-Baltistan", lcol(midblue%70) mcol(midblue%70) lwidth(thin) msize(small) msymbol(square)) ///
	(connect tpres year if province == "Islamabad - ICT", lcol(lavender%70) mcol(lavender%70) msize(small) lpattern(dash)) ///
	(connect tpres year if province == "Khyber Pakhtunkhwa", lcol(ebblue%70) mcol(ebblue%70) msize(small) lpattern(dash) msymbol(triangle)) ///
	(connect tpres year if province == "FATA", lcol(emidblue%70) mcol(emidblue%70) msize(small) lpattern(dash) msymbol(diamond)) ///
	(connect tpres year if province == "AJK", lcol(gs11%70) mcol(gs11%70) msize(small) lpattern(dash) msymbol(square)), ///	
	ytitle("Average teacher presence", size(vlarge)) yscale(r(60 100)) ylabel(60(5)100, nogrid)  ///
	xlabel(2010(1)2016, nogrid) xtitle(Year, size(vlarge)) xline(2011.5) ///
	legend(order(1 "Punjab" 2 "Sindh" 3 "Balochistan" 4 "GB" ///
		5 "Islamabad" 6 "KP" 7 "FATA" 8 "AJK") col(4) size(vlarge) region(lstyle(none)) pos(6)) ///
	graphregion(col(white))
	
graph export "$analysis/figures/descriptive/FigureA1_tpres.pdf", replace

twoway (connect satt year if province == "Punjab", lwidth(thick)) ///
	(connect satt year if province == "Sindh", lcol(navy%70) mcol(navy%70) lwidth(thin) msize(small) msymbol(triangle)) ///
	(connect satt year if province == "Balochistan", lcol(blue%70) mcol(blue%70) lwidth(thin) msize(small) msymbol(diamond)) ///
	(connect satt year if province == "Gilgit-Baltistan", lcol(midblue%70) mcol(midblue%70) lwidth(thin) msize(small) msymbol(square)) ///
	(connect satt year if province == "Islamabad - ICT" & year < 2016, lcol(lavender%70) mcol(lavender%70) msize(small) lpattern(dash)) ///
	(connect satt year if province == "Khyber Pakhtunkhwa", lcol(ebblue%70) mcol(ebblue%70) msize(small) lpattern(dash) msymbol(triangle)) ///
	(connect satt year if province == "FATA", lcol(emidblue%70) mcol(emidblue%70) msize(small) lpattern(dash) msymbol(diamond)) ///
	(connect satt year if province == "AJK", lcol(gs11%70) mcol(gs11%70) msize(small) lpattern(dash) msymbol(square)), ///	
	yscale(r(60 100)) ylabel(60(5)100, nogrid) ytitle("Average student attendance", size(vlarge)) ///
	xlabel(2010(1)2016, nogrid) xtitle(Year, size(vlarge)) xline(2011.5) ///
	legend(order(1 "Punjab" 2 "Sindh" 3 "Balochistan" 4 "GB" ///
		5 "Islamabad" 6 "KP" 7 "FATA" 8 "AJK") col(4) size(vlarge) region(lstyle(none)) pos(6)) ///
	graphregion(col(white))
	
graph export "$analysis/figures/descriptive/FigureA1_satt.pdf", replace

twoway (connect fac year if province == "Punjab", lwidth(thick)) ///
	(connect fac year if province == "Sindh", lcol(navy%70) mcol(navy%70) lwidth(thin) msize(small) msymbol(triangle)) ///
	(connect fac year if province == "Balochistan", lcol(blue%70) mcol(blue%70) lwidth(thin) msize(small) msymbol(diamond)) ///
	(connect fac year if province == "Gilgit-Baltistan", lcol(midblue%70) mcol(midblue%70) lwidth(thin) msize(small) msymbol(square)) ///
	(connect fac year if province == "Islamabad - ICT" & year < 2016, lcol(lavender%70) mcol(lavender%70) msize(small) lpattern(dash)) ///
	(connect fac year if province == "Khyber Pakhtunkhwa", lcol(ebblue%70) mcol(ebblue%70) msize(small) lpattern(dash) msymbol(triangle)) ///
	(connect fac year if province == "FATA", lcol(emidblue%70) mcol(emidblue%70) msize(small) lpattern(dash) msymbol(diamond)) ///
	(connect fac year if province == "AJK", lcol(gs11%70) mcol(gs11%70) msize(small) lpattern(dash) msymbol(square)), ///	
	yscale(r(20 100)) ylabel(20(10)100, nogrid) ytitle("Average functional facilities", size(vlarge)) ///
	xlabel(2010(1)2016, nogrid) xtitle(Year, size(vlarge)) xline(2011.5) ///
	legend(order(1 "Punjab" 2 "Sindh" 3 "Balochistan" 4 "GB" ///
		5 "Islamabad" 6 "KP" 7 "FATA" 8 "AJK") col(4) size(vlarge) region(lstyle(none)) pos(6)) ///
	graphregion(col(white))
	
graph export "$analysis/figures/descriptive/FigureA1_fac.pdf", replace
	
}

*---------------------------------------------------------------------------------------------------
**# 8. data validation: distribution and errors in reporting #

***** Figure A3				
/*under the assumption that the monthly data is not as independent as the census, we compare both 
data sources to ensure the quality of the data. For this we only have number of teachers posted, 
enrollment and functional facilities
 
We proceed in the following way:
 
For each year between 2012 and 2017 we compare the distribution
For each year we plot the differences
 
We compare the annual census with each november as is the closest date to the date of census 
collection

notes on this: census data for all schools, but monthly for near of the 80% per markaz randonly,
so we only check those in both
*/
			
*census data: independently collected once a year

if(1){
	
preserve

use "$data/anualschoolcensus", clear

*standardize columns
rename emiscode emis
rename year_new year
rename total_teachers_new totalteachers
rename total_school_enrollment_new totalenrol
rename electricity_new elec_f
rename drinking_water_new dw_f
rename toilet_new toilet_f
rename building_new bw_f
keep emis year totalteachers totalenrol elec_f dw_f toilet_f bw_f 
sort emis year
gen random = runiform()
sort emis year random
bys emis year (random): gen ord = _n
keep if ord == 1
drop random ord
drop if year < 2012
gen census = 1
tempfile temp
save `temp'

restore

*original monthly data: not cleaned or adjusted version
use "$data/cc_mea_master.dta", clear 

*create necessary columns
egen totalenrol = rowtotal(cls1enrol cls2enrol cls3enrol cls4enrol cls5enrol cls6enrol cls7enrol ///
	cls8enrol cls9enrol cls10enrol cls11enrol cls12enrol)
replace totalenrol = . if totalenrol == 0
keep if month == 11 
keep emis year totalteachers totalenrol elec_f dw_f toilet_f bw_f 

sort emis year
gen random = runiform()
sort emis year random
bys emis year (random): gen ord = _n
keep if ord == 1
drop random ord
drop if year < 2012 | year > 2017
gen census = 0

*append both data sources
append using `temp'

*keep only those appearing in both samples
bys emis year: egen c = count(census)
keep if c == 2
drop c

local vars tpres satt fac
foreach v of local vars{
	
	if("`v'" == "tpres"){
			
		* teacher presence
		
			*distribution of overlapping variables
		preserve
		replace totalteachers = ln(totalteachers + 1)
		*plot distribution of both variables
		twoway (kdensity totalteachers if census == 1, color(blue%40) recast(area)) ///
		(kdensity totalteachers if census == 0, color(red%20) recast(area)), ///
			by(year , graphregion(fcolor(white)) legend(position(6))) ///
			graphregion(color(white)) plotregion(color(white)) ///
			xtitle("Number of teachers (logs)", size(vlarge)) ytitle("Density", size(vlarge)) ylabel(, nogrid) ///
			legend(order(1 "Census" 2 "PMIU") size(vlarge) region(lstyle(none)) col(2) position(6))
			
		graph export "$analysis/figures/descriptive/FigureA3_tpres.pdf", replace
		restore			

	}
	else if("`v'" == "satt"){
			
		* student attendance

			*distribution of overlapping variables
		preserve
		replace totalenrol = ln(totalenrol + 1)
		*plot distribution of both variables
		twoway (kdensity totalenrol if census == 1, color(blue%40) recast(area)) ///
			(kdensity totalenrol if census == 0, color(red%30) recast(area)), ///
			by(year , graphregion(fcolor(white)) legend(position(6))) ///
			graphregion(color(white)) plotregion(color(white)) ///
			xtitle("Number of students (logs)", size(vlarge)) ytitle("Density", size(vlarge)) ylabel(, nogrid) ///
			legend(order(1 "Census" 2 "PMIU") size(vlarge) region(lstyle(none)) col(2) position(6))
			
		graph export "$analysis/figures/descriptive/FigureA3_satt.pdf", replace
		restore
			
	}
	else if("`v'" == "fac"){
			
		/*functional facilities is acatyegorical variable, then we only plot the percentage of 
		coincidence*/
			
		preserve
		local vars elec_f dw_f bw_f toilet_f
		foreach v of local vars{
			bys emis year (census): gen coincide_`v' = (`v'[_n] == `v'[_n+1])				
		}

		local vars elec_f dw_f bw_f toilet_f
		foreach v of local vars{	
			bys emis year (census): egen coincide_`v'_max = max(coincide_`v')						
		}

		drop if census == 1

		gen counter = 1

		collapse (sum) coincide_elec_f_max coincide_dw_f_max coincide_bw_f_max ///
			coincide_toilet_f_max counter, by(year)
		local vars elec_f dw_f bw_f toilet_f
		foreach v of local vars{	
			gen perc_`v' = (coincide_`v'_max/counter)*100 						
		}
		
		grstyle init
		grstyle set color "navy" "cranberry"  "green" "orange"

		graph bar perc_elec_f perc_dw_f perc_toilet_f perc_bw_f, ///
			by(year , graphregion(fcolor(white)) legend(position(6)) ///
			) ///
			ytitle("% coincidence - Census and PMIU", size(vlarge)) ylabel(, nogrid) ///
			legend(order(1 "Electricity" 2 "Drink water" 3 "Toilet" 4 "Building") region(lstyle(none)) col(4) size(vlarge) position(6)) 

			
		graph export "$analysis/figures/descriptive/FigureA3_fac.pdf", replace
		restore

	}
	
}

}

