 /*--------------------------------------------------------------------------------------------------
Stacked analysis

	Outline:

	1. markaz red flagging
		- Figure D1
		- Table D1
		- Figure D2
		
	2. markaz red flagging - first time
		- Figure D3
	
	3. markaz red flagging - short stack
		- Figure D4

	4. markaz red flagging with flagging history
		- Table D2

	5. markaz orange flagging stacking
		- Figure D5
		
	6. tehsil red flagging stacking	
		- Figure D6
				
    7. alternative difference in differences estimators 
		- Figure D7
		- Figure D8

--------------------------------------------------------------------------------------------------*/

* programs: event study graphs

/* we will be doing a lot of event study graphs, to avoid repeating long chunks of code we set up 
some programs 
*/

/* program for long event studies
- main analysis
- short stack analysis
- tehsil flagging
- first flag 
*/
capture program drop eventgraph
program define eventgraph

	* arguments of the function
	args yvar full rd xl yl ymin ymax bet height flag punish after typeg
	
	/*
	yvar: outcome
	baseper: base period
	xl: base period line
	yl: zero line
	ymin: min ylabel 
	ymax: max ylabel
	bet: spacing between labels
	height: height of text for periods
	flag punish after: location in x axis of text for each period
	typeg: 
	
		1: long stack
		2: short stack
		3: neighbor effects in spillover specification
		4: reversion to the mean
	*/
		
	* plot
	if(`typeg' == 1){
	
		coefplot (`full', offset(0.1) mcol(navy) lcol(navy) lpattern(solid) ciopts(recast(rcap) lcol(navy))) /// full sample coefficients
				 (`rd', offset(-0.1) mcol(cranberry) lcol(cranberry) lpattern(solid) ciopts(recast(rcap) lcol(cranberry))), /// threshold sample coefficient
				 recast(connect) lw(vvthin) /// connected graph
				 baselevels /// include baselevel
				 omitted /// include ommited period (-1)
				 level(95) /// 95% confidence intervals
				 /// type of confidence intervals
				 vertical /// vertical oriented graph 
				 ///mcol(%30) /// transparency of points
				 keep( /// interactions to keep in the graph
					  1.flagged#1.time_id 1.flagged#2.time_id 1.flagged#3.time_id ///
					  1.flagged#4.time_id 1.flagged#5.time_id 1.flagged#6.time_id ///
					  1.flagged#7.time_id 1.flagged#8.time_id 1.flagged#9.time_id ///
					  1.flagged#10.time_id 1.flagged#11.time_id ///
				) /// 
				addplot( /// additional graph details to include
					  scatteri `ymax' 4.5 `ymax' 5.49, recast(area) lwidth(none) col(gs14%50) below || ///
					  scatteri -`ymin' 4.5 -`ymin' 5.49, recast(area) lwidth(none) col(gs14%50) below || ///
					  scatteri `ymax' 5.5 `ymax' 6.49, recast(area) lwidth(none) col(gs12%50) below || ///
					  scatteri -`ymin' 5.5 -`ymin' 6.49, recast(area) lwidth(none) col(gs12%50) below || ///
					  scatteri `ymax' 6.5 `ymax' 11.49, recast(area) lwidth(none) col(gs8%50) below || ///
					  scatteri -`ymin' 6.5 -`ymin' 11.49, recast(area) lwidth(none) col(gs8%50) below ///
				) ///
				yline(`yl', lcol("black") lpattern(dash)) /// y line for 0
				xline(`xl', lpattern("dash") lcol("black")) /// x line for initial period
				xlabel(, nogrid) ///
				yscale(r(-`ymin' `ymax')) /// y scale
				ylabel(-`ymin'(`bet')`ymax', nogrid) /// y label
				graphregion(color(white)) /// white background
				xtitle("Relative time", size(vlarge)) /// xtitle
				ytitle("Coefficient (pp)", size(vlarge)) /// ytitle
				title("", size(vsmall) col(black)) /// no title
				text( /// text for each post period
					`height' `flag' "{bf: Flag}" `height' `punish' "{bf:Punish}" `height' `after' "{bf:After}" "{bf:flag}", size(vlarge) ///
						orient(vertical) placement(c) ///
				) ///
				coeflabel( /// label of coefficients
					1.flagged#1.time_id = "-4" 1.flagged#2.time_id = "-3" 1.flagged#3.time_id = "-2" ///
					1.flagged#4.time_id = "-1" 1.flagged#5.time_id = "0" 1.flagged#6.time_id = "1" ///
					1.flagged#7.time_id = "2" 1.flagged#8.time_id = "3" 1.flagged#9.time_id = "4"  ///
					1.flagged#10.time_id = "5" 1.flagged#11.time_id = "6" ///
				) ///
				legend(label(8 "Full sample") label(10 "Threshold sample") size(vlarge) region(lstyle(none)) pos(6) col(2)) // legend
				
	}
	else if(`typeg' == 2){
		
		coefplot (`full', offset(0.1) mcol(navy) lcol(navy) lpattern(solid) ciopts(recast(rcap) lcol(navy))) /// full sample coefficients
				 (`rd', offset(-0.1) mcol(cranberry) lcol(cranberry) lpattern(solid) ciopts(recast(rcap) lcol(cranberry))), /// threshold sample coefficient
				 recast(connect) lw(vvthin) /// connected graph
				 baselevels /// include baselevel
				 omitted /// include ommited period (-1)
				 level(95) /// 95% confidence intervals
				 ciopts(recast(rcap)) /// type of confidence intervals
				 vertical /// vertical oriented graph 
				 ///mcol(%30) /// transparency of points
				 keep( /// interactions to keep in the graph
					  1.flagged#1.time_id 1.flagged#2.time_id 1.flagged#3.time_id ///
					  1.flagged#4.time_id 1.flagged#5.time_id 1.flagged#6.time_id ///
					  1.flagged#7.time_id 1.flagged#8.time_id ///
				) /// 
				addplot( /// additional graph details to include
					  scatteri `ymax' 4.5 `ymax' 5.49, recast(area) lwidth(none) col(gs14%50) below || ///
					  scatteri -`ymin' 4.5 -`ymin' 5.49, recast(area) lwidth(none) col(gs14%50) below || ///
					  scatteri `ymax' 5.5 `ymax' 6.49, recast(area) lwidth(none) col(gs12%50) below || ///
					  scatteri -`ymin' 5.5 -`ymin' 6.49, recast(area) lwidth(none) col(gs12%50) below || ///
					  scatteri `ymax' 6.5 `ymax' 8.49, recast(area) lwidth(none) col(gs8%50) below || ///
					  scatteri -`ymin' 6.5 -`ymin' 8.49, recast(area) lwidth(none) col(gs8%50) below ///
				) ///
				yline(`yl', lcol("black") lpattern(dash)) /// y line for 0
				xline(`xl', lpattern("dash") lcol("black")) /// x line for initial period
				xlabel(, nogrid) ///
				yscale(r(-`ymin' `ymax')) /// y scale
				ylabel(-`ymin'(`bet')`ymax', nogrid) /// y label
				graphregion(color(white)) /// white background
				xtitle("Relative time", size(vlarge)) /// xtitle
				ytitle("Coefficient (pp)", size(vlarge)) /// ytitle
				title("", size(vsmall) col(black)) /// no title
				text( /// text for each post period
					`height' `flag' "{bf: Flag}" `height' `punish' "{bf:Punish}" `height' `after' "{bf:After}" "{bf:flag}", size(vlarge) ///
						orient(vertical) placement(c) ///
				) ///
				coeflabel( /// label of coefficients
					1.flagged#1.time_id = "-4" 1.flagged#2.time_id = "-3" 1.flagged#3.time_id = "-2" ///
					1.flagged#4.time_id = "-1" 1.flagged#5.time_id = "0" 1.flagged#6.time_id = "1" ///
					1.flagged#7.time_id = "2" 1.flagged#8.time_id = "3" ///
				) ///
				legend(label(8 "Full sample") label(10 "Threshold sample") size(vlarge) region(lstyle(none)) pos(6) col(2)) // legend
	}
	
end

*---------------------------------------------------------------------------------------------------
**# 1. regressions: markaz red flagging #

***** Figure D1
global treatments tpres satt fac math eng urdu //
foreach yvar of global treatments{
	
	*main data set
		
	use "$analysis/processed/stacked/cc_stackdata5_`yvar'.dta", clear
	
	local baseper = 4 // define base period
	
	*full regression
	eststo full: reghdfe `yvar' i.flagged##ib(`baseper').time_id [aw = avg_totalreportedteachers_mar], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 

	*threshold sample regression
	eststo rd: reghdfe `yvar' i.flagged##ib(`baseper').time_id if rd1 == 1 [aw = avg_totalreportedteachers_mar], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 
		
	*set graph parameters
	
	// constant
	local xl     = 4
	local yl     = 0
	local flag   = 5
	local punish = 6 
	local after  = 9.5
	local typeg = 1
	
	// changing
	if("`yvar'" == "tpres" | "`yvar'" == "satt" | "`yvar'" == "fac"){
		
		local ymax   = 6
		local ymin   = 8
		local bet    = 2
		local height = 4.2
	
	} 
	else{ // parameters for scores 
	
		local ymax   = 12
		local ymin   = 16
		local bet    = 4
		local height = 8.8
		
	}

	*plot 
	
	eventgraph `yvar' full rd `xl' `yl' `ymin' `ymax' `bet' `height' `flag' `punish' `after' `typeg'
	
	* save graph

	graph export "$analysis/figures/causal/FigureD1_`yvar'.pdf", replace		

}

***** Table D1
global treatments tpres satt fac math eng urdu 
foreach yvar of global treatments{
	
	*main data set
	
	use "$analysis/processed/stacked/cc_stackdata5_`yvar'.dta", clear
	
	*variables for each period
	
	gen flag = (relativetime == 0)
	gen punish = (relativetime == 1)
	gen afterflag = (relativetime >= 2)
	
	*label values
	
	label define f 0 "Before" 1 "Flag"
	label values flag f
	label define p 0 "Before" 1 "Punish"
	label values punish p
	label define a 0 "Before" 1 "After flag"
	label values afterflag a
	label define t 0 "No T" 1 "T"
	label values flagged t
	
	*label
	
	label var flag "Flag"
	label var punish "Punish"
	label var afterflag "After flag"
	label var flagged "T"
	
	* full regression
	eststo full`yvar': reghdfe `yvar' i.flagged##i.flag i.flagged##i.punish i.flagged##i.afterflag ///
		[aw = avg_totalreportedteachers_mar], ///
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 
	qui estadd ysumm
	qui sum `yvar' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `yvar' if e(sample) & relativetime == 0 
	qui estadd scalar ymeanbef `r(mean)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local samp "Full"



	* rd regression
	eststo rd`yvar': reghdfe `yvar' i.flagged##i.flag i.flagged##i.punish i.flagged##i.afterflag ///
		if rd1 == 1 [aw = avg_totalreportedteachers_mar], ///
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 
	qui estadd ysumm
	qui sum `yvar' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `yvar' if e(sample) & relativetime == 0 
	qui estadd scalar ymeanbef `r(mean)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local samp "Threshold"


}

if(1){
	
estout fulltpres rdtpres fullsatt rdsatt fullfac rdfac /// models
	using "$analysis/tables/causal/1_flagging_outcomes.tex", /// file
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	keep(1.flagged#1.flag 1.flagged#1.punish 1.flagged#1.afterflag) /// coefficients to keep
	order(1.flagged#1.flag 1.flagged#1.punish 1.flagged#1.afterflag) /// order coefficients
	label interact("$\times$") /// interations
	prehead(\begin{tabular}{lcccccc} \toprule  ///
	 "\multicolumn{7}{l}{\textbf{Panel A: School outcomes}} \\" ///
	 "& \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" ///
	 "& \multicolumn{2}{c}{Teacher presence} & \multicolumn{2}{c}{Student attendance} & \multicolumn{2}{c}{Functional facilities} \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	prefoot(\midrule ) ///
	stats(samp N ymeanbef, fmt(a2 %11.2gc a2) ///
	labels("Sample" "N. of obs." "Mean Dep. Var. before")) /// stats to keep
	replace // replace if it exist
	
estout fullmath rdmath fulleng rdeng fullurdu rdurdu /// models
	using "$analysis/tables/causal/TableD1.tex", /// file
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	keep(1.flagged#1.flag 1.flagged#1.punish 1.flagged#1.afterflag) /// coefficients to keep
	order(1.flagged#1.flag 1.flagged#1.punish 1.flagged#1.afterflag) /// order coefficients
	label interact("$\times$") /// interations
	prehead("\midrule \multicolumn{7}{l}{\textbf{Panel B: Students scores}} \\" ///
	 "& \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" ///
	 "& \multicolumn{2}{c}{Math} & \multicolumn{2}{c}{English} & \multicolumn{2}{c}{Urdu} \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) /// this set end to table, note we put it here as we want to append panels
	stats(samp N ymeanbef marfe timefe disfe , fmt(a2 %11.2gc a2 a2 a2 a2) ///
	labels("Sample" "N. of obs." "Mean Dep. Var. before" "\midrule Markaz FE" "Time FE" "District time trends")) /// stats to keep
	topfile("$analysis/tables/causal/1_flagging_outcomes.tex") /// this joins the two panels into a single table
	replace // replace if it exist
	
}

***** Figure D2
global treatments tpres satt fac math eng urdu // 
foreach yvar of global treatments{
	
	*main data set
	use "$analysis/processed/stacked/cc_stackdata5_`yvar'.dta", clear
	
	*size of the dip
	// value in pre-schock
	bys stack mar: egen temp = mean(mar_`yvar') if time_id <= 4 
	bys stack mar: egen premean = max(temp)
	drop temp
	// value in the shock
	bys stack mar: egen temp = mean(mar_`yvar') if time_id == 5 
	bys stack mar: egen shock = max(temp)
	drop temp
	// value in punish
	bys stack mar: egen temp = mean(mar_`yvar') if time_id == 6 
	bys stack mar: egen postmean = max(temp) 
	drop temp
	// descriptive of diff
	gen diff = postmean - premean 
	sum diff if diff < 0 , d
	// gen recovered
	gen recovered =  (diff >= `r(p75)') // closer to 0, then they would have already recovered for punish period
	// collapse at the mar level: detrended at the aggregate level
	collapse (mean) `yvar' avg_totalreportedteachers, by(stack mar time_id district flagged recovered rd1)
	bys stack mar (time_id): gen detrend = `yvar' - `yvar'[_n-1]
	
	*run month to month regression

	// month by month difference in average
	
	forvalues i = 1(1)10{
		
		local baseper = `i'
		local next    = `i'+1
		eststo full: reghdfe `yvar' i.flagged##ib(`baseper').time_id ///
		if time_id >= `i' & time_id <= `next' & ///
		recovered == 0 [aw = avg_totalreportedteachers_mar], ///
		absorb(mar#stack time_id#stack stack#district##c.time_id) vce(cluster mar) 
		matrix C = e(b)[1,8] // coefficient
		matrix A = sqrt(e(V)[8,8])
		matrix g`i' = (C \ A)
		
	}
	
	matrix D = (g1[1,1], g1[2,1] \ g2[1,1], g2[2,1] \ g3[1,1], g3[2,1] \ ///
				g4[1,1], g4[2,1] \ g5[1,1], g5[2,1] \ g6[1,1], g6[2,1] \ ///
				g7[1,1], g7[2,1] \ g8[1,1], g8[2,1] \ g9[1,1], g9[2,1] \ ///
				g10[1,1], g10[2,1])
				
				
// month by month difference in average in threshold sample
				
	forvalues i = 1(1)10{
		
		local baseper = `i'
		local next    = `i'+1
		eststo rd: reghdfe `yvar' i.flagged##ib(`baseper').time_id ///
		if time_id >= `i' & time_id <= `next' & ///
		recovered == 0 & rd1 == 1 [aw = avg_totalreportedteachers_mar], ///
		absorb(mar#stack time_id#stack stack#district##c.time_id) vce(cluster mar) 
		matrix C = e(b)[1,8] // coefficient
		matrix A = sqrt(e(V)[8,8])
		matrix g`i' = (C \ A)
		
	}
	
	matrix E = (g1[1,1], g1[2,1] \ g2[1,1], g2[2,1] \ g3[1,1], g3[2,1] \ ///
				g4[1,1], g4[2,1] \ g5[1,1], g5[2,1] \ g6[1,1], g6[2,1] \ ///
				g7[1,1], g7[2,1] \ g8[1,1], g8[2,1] \ g9[1,1], g9[2,1] \ ///
				g10[1,1], g10[2,1])				
				

	local xl     = 3.5
	local yl     = 0
	local flag   = 4
	local punish = 5 
	local after  = 8
	
	if("`yvar'" == "tpres" | "`yvar'" == "satt" | "`yvar'" == "fac" ){
		
		local ymax   = 6
		local ymin   = 14
		local bet    = 2
		local height = -10.2
		
	}
	else{
		
		local ymax   = 12
		local ymin   = 20
		local bet    = 4
		local height = -16.2
		
	}
	
// plot of the two set of results

	grstyle init
	grstyle set color "navy" "cranberry" 
	
	coefplot (matrix(D[,1]), se(D[,2]) mcol(navy) lcol(navy) lpattern(solid) ciopts(recast(rcap) lcol(navy))) ///
			(matrix(E[,1]), se(E[,2]) mcol(cranberry) lcol(cranberry) lpattern(solid) ciopts(recast(rcap) lcol(cranberry))), /// coefficients and standard error matrix
			 recast(connect) lw(vvthin) /// connected graph
			 baselevels /// include baselevel
			 omitted /// include ommited period (-1)
			 level(95) /// 95% confidence intervals
			 ciopts(recast(rcap)) /// type of confidence intervals
			 vertical /// vertical oriented graph 
			 mcol(%30) /// transparency of points
			 addplot( /// additional graph details to include
				  scatteri `ymax' 3.5 `ymax' 4.49, recast(area) lwidth(none) col(gs14%50) below || ///
				  scatteri -`ymin' 3.5 -`ymin' 4.49, recast(area) lwidth(none) col(gs14%50) below || ///
				  scatteri `ymax' 4.5 `ymax' 5.49, recast(area) lwidth(none) col(gs12%50) below || ///
				  scatteri -`ymin' 4.5 -`ymin' 5.49, recast(area) lwidth(none) col(gs12%50) below || ///
				  scatteri `ymax' 5.5 `ymax' 10.49, recast(area) lwidth(none) col(gs8%50) below || ///
				  scatteri -`ymin' 5.5 -`ymin' 10.49, recast(area) lwidth(none) col(gs8%50) below ///
			) ///
			yline(`yl', lcol("black") lpattern(dash)) /// y line for 0
			xline(`xl', lpattern("dash") lcol("black")) /// x line for initial period
			yscale(r(-`ymin' `ymax')) /// y scale
			ylabel(-`ymin'(`bet')`ymax', nogrid) /// y label
			xlabel(, nogrid) ///
			graphregion(color(white)) /// white background
			xtitle("Relative time", size(large)) /// xtitle
			ytitle("Month on month change", size(large)) /// ytitle
			title("", size(vsmall) col(black)) /// no title
			text( /// text for each post period
				`height' `flag' "{bf: Flag}" `height' `punish' "{bf:Punish}" `height' `after' "{bf:After}" "{bf:flag}", size(large) ///
					orient(vertical) placement(c) ///
			) ///
			coeflabel( /// label of coefficients
				r1 = "-3" r2 = "-2" r3 = "-1" r4 = "0" r5 = "1" r6 = "2" r7 = "3" ///
				r8 = "4"  r9 = "5" r10 = "6" ///
			) ///
			legend(label(8 "Full sample") label(10 "Threshold sample") size(large) region(lstyle(none)) pos(6) cols(2))
			
	* save graph

	graph export "$analysis/figures/causal/FigureD2_`yvar'.pdf", replace		


}

/*pvalue - threshold sample Figure 7

global treatments tpres satt fac math eng urdu 
foreach yvar of global treatments{

	*main data set
	use "$analysis/processed/stacked/cc_stackdata5_`yvar'.dta", clear
	
	*size of the dip
	// value in pre-schock
	bys stack mar: egen temp = mean(mar_`yvar') if time_id <= 4 
	bys stack mar: egen premean = max(temp)
	drop temp
	// value in the shock
	bys stack mar: egen temp = mean(mar_`yvar') if time_id == 5 
	bys stack mar: egen shock = max(temp)
	drop temp
	// value in punish
	bys stack mar: egen temp = mean(mar_`yvar') if time_id == 6 
	bys stack mar: egen postmean = max(temp) 
	drop temp
	// descriptive of diff
	gen diff = postmean - premean 
	sum diff if diff < 0 , d
	// gen recovered
	gen recovered =  (diff >= `r(p75)')
	// collapse at the mar level: detrended at the aggregate level
	collapse (mean) `yvar' avg_totalreportedteachers, by(stack mar time_id district flagged recovered rd1)
	bys stack mar (time_id): gen detrend = `yvar' - `yvar'[_n-1]
			
// month by month difference in average
	
	forvalues i = 5(1)6{
		
		preserve
		
		local baseper = `i'
		local next    = `i'+1
		keep if time_id >= `i' & time_id <= `next'
		replace time_id = 0 if time_id == `i'
		replace time_id = 1 if time_id == `next'
		
		gen group = `i'
		tempfile temp`i'
		save `temp`i''
		
		restore
				
	}	
	
	* we append both to run the mmore easily
	use `temp5', clear
	append using `temp6'
	
	*gen flagging

	gen treat = flagged * time_id // create treatment status to make the test easier
	
	/*important note! 
	
	reghdfe is not compatible to testing hypothesis across models (like in this case). Usually we 
	would be able to use test or lincom as they come from the same regression, but comparing across 
	regressions with that amount of FE might be difficult, as we have to go back to use the usual 
	reg command
	
	to address the issue we will apply FWL theorem
	
	*/
	forvalues i = 5(1)6{

	* 1. regress the diff in diff interaction on the fixed effects
		reghdfe treat if recovered == 0 & rd1 == 1 & group == `i' [aw = avg_totalreportedteachers_mar], ///
			absorb(mar#stack time_id#stack district##stack##c.time_id) vce(cluster mar) resid
		predict rtreat`i', resid
		
	* 2. regress the outcome on the the fixed effects
		reghdfe `yvar' if recovered == 0 & rd1 == 1 & group == `i' [aw = avg_totalreportedteachers_mar], ///
			absorb(mar#stack time_id#stack district##stack##c.time_id) vce(cluster mar) resid
		predict r`yvar'`i', resid
		
		*regress the residuals from 2 against the residuals in 1
		eststo r`i': reg r`yvar'`i' rtreat`i' if recovered == 0 & rd1 == 1 & group == `i'
			
	}
	
	
	// we see that the coefficients are the same from those of the figure, as well as the sd
	suest r5 r6, vce(cluster mar)
	// lincom and test perform a two sided test! we need to adjust to one sided
	test   [r6_mean]rtreat6 - [r5_mean]rtreat5 = 0 // wald test
	local sign_test = sign([r6_mean][rtreat6]-[r5_mean][rtreat5]) // sign of the wald test difference

	/*test 1: 
	test if the difference in the coefficients is significant, but sign matters
		- if positive: 1 - alpha
		- if negative: alpha
	*/
		
	if(`sign_test' == 1){
		display "one sided wald test for `yvar'" = 1 - normal(`sign_test'*sqrt(r(chi2)))
	}
	else if(`sign_test' == -1){
		display "one sided wald test for `yvar'" = normal(`sign_test'*sqrt(r(chi2)))
	}
	
	/*test 2: 
	test if the difference in the coefficients is positive and significant
		- if positive: 1 - alpha
		- if negative: 1 - alpha as we still want to test if the difference is positive
	*/
	
	display "one sided wald test for `yvar'" = 1 - normal(`sign_test'*sqrt(r(chi2)))
	
}
*/

*--------------------------------------------------------------------------------------------------- 
**# 2. regressions: first time flagged # 

***** Figure D3
global treatments tpres satt fac // only for outcomes available since the implementation
foreach yvar of global treatments{

	*main data set
	
	use "$analysis/processed/stacked/cc_stackdata5_`yvar'.dta", clear
		
	*keep unique stack schools to account for flagging in each stack
	/*identify which stack schools were flagged, and for those identify the neighbors of the same 
	tehsil
	*/
	
	*regressions
	
	local baseper = 4 // define base period

	* full
	eststo full: reghdfe `yvar' i.flagged##ib(`baseper').time_id  ///
		if stack >= 10 & stack <= 11 [aw = avg_totalreportedteachers_mar], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) ///
		vce(cluster mar) 

	* rd
	eststo rd: reghdfe `yvar' i.flagged##ib(`baseper').time_id ///
		if rd1 == 1 & stack >= 10 & stack <= 11 [aw = avg_totalreportedteachers_mar], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) ///
		vce(cluster mar) 
	
	*define parameters for  plotting
	
	// constant
	local xl = 4
	local yl = 0	
	local ymax = 16
	local ymin = 16
	local bet = 4
	local height = 8.8
	local flag   = 5
	local punish = 6 
	local after  = 9.5
	local typeg = 1
	
	*for main flagged
	
	eventgraph `yvar' full rd `xl' `yl' `ymin' `ymax' `bet' `height' `flag' `punish' `after' `typeg'
	
	* save graph

	graph export "$analysis/figures/causal/FigureD3_`yvar'.pdf", replace		

}

*---------------------------------------------------------------------------------------------------
**# 3. regressions: markaz red flagging - short stack #

***** Figure D4
global treatments tpres satt fac math eng urdu // 
foreach yvar of global treatments{
	
	*main data set
	
	use "$analysis/processed/stacked/cc_stackdata2_`yvar'.dta", clear
	
	local baseper = 4 // define base period
	
	*full regression
	eststo full: reghdfe `yvar' i.flagged##ib(`baseper').time_id [aw = avg_totalreportedteachers_mar], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 

	*threshold sample regression
	eststo rd: reghdfe `yvar' i.flagged##ib(`baseper').time_id if rd1 == 1 [aw = avg_totalreportedteachers_mar], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 
		
	*set graph parameters
	
	// constant
	local xl     = 4
	local yl     = 0
	local flag   = 5
	local punish = 6 
	local after  = 7.5
	local typeg  = 2

	
	// changing
	if("`yvar'" == "tpres" | "`yvar'" == "satt" | "`yvar'" == "fac"){
		
		local ymax   = 6
		local ymin   = 8
		local bet    = 2
		local height = 4.2
	
	} 
	else{ // parameters for scores 
	
		local ymax   = 12
		local ymin   = 16
		local bet    = 4
		local height = 8.8
		
	}

	*plot 
	
	eventgraph `yvar' full rd `xl' `yl' `ymin' `ymax' `bet' `height' `flag' `punish' `after' `typeg'
	
	* save graph

	graph export "$analysis/figures/causal/FigureD4_`yvar'.pdf", replace		

}

*---------------------------------------------------------------------------------------------------
**# 4. regressions: markaz red flagging - flagging history fixed effects #

* from here onwards we are using different aggregations whre district is not necesary edundant, the nwe use the traditional version district#c.time fixed effects

***** Table D2
global treatments tpres satt fac math eng urdu 
foreach yvar of global treatments{
	
	*main data set
	
	use "$analysis/processed/stacked/cc_stackdata5_`yvar'_flaghist.dta", clear
	
	*variables for each period
	
	gen flag = (relativetime == 0)
	gen punish = (relativetime == 1)
	gen afterflag = (relativetime >= 2)
	
	*label values
	
	label define f 0 "Before" 1 "Flag"
	label values flag f
	label define p 0 "Before" 1 "Punish"
	label values punish p
	label define a 0 "Before" 1 "After flag"
	label values afterflag a
	label define t 0 "No T" 1 "T"
	label values flagged t
	
	*label
	
	label var flag "Flag"
	label var punish "Punish"
	label var afterflag "After flag"
	label var flagged "T"
	
	* full regression
	eststo full`yvar': reghdfe `yvar' i.flagged##i.flag i.flagged##i.punish i.flagged##i.afterflag ///
		[aw = avg_totalreportedteachers_mar], ///
		absorb(`yvar'_flag_hist#stack time_id#stack district#stack#c.time_id) vce(cluster mar) 
	qui estadd ysumm
	qui sum `yvar' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `yvar' if e(sample) & relativetime == 0 
	qui estadd scalar ymeanbef `r(mean)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local samp "Full"

	* rd regression
	eststo rd`yvar': reghdfe `yvar' i.flagged##i.flag i.flagged##i.punish i.flagged##i.afterflag ///
		if rd1 == 1 [aw = avg_totalreportedteachers_mar], ///
		absorb(`yvar'_flag_hist#stack time_id#stack district#stack#c.time_id) vce(cluster mar) 
	qui estadd ysumm
	qui sum `yvar' if e(sample)
	qui estadd scalar yobs `r(N)'
	qui sum `yvar' if e(sample) & relativetime == 0 
	qui estadd scalar ymeanbef `r(mean)'
	qui estadd local marfe "Yes"
	qui estadd local timefe "Yes"
	qui estadd local disfe "Yes"
	qui estadd local samp "Threshold"


}

if(1){
	
estout fulltpres rdtpres fullsatt rdsatt fullfac rdfac /// models
	using "$analysis/tables/causal/1_flagging_outcomes_hist.tex", /// file
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	keep(1.flagged 1.flagged#1.flag 1.flagged#1.punish 1.flagged#1.afterflag) /// coefficients to keep
	order(1.flagged 1.flagged#1.flag 1.flagged#1.punish 1.flagged#1.afterflag) /// order coefficients
	label interact("$\times$") /// interations
	prehead(\begin{tabular}{lcccccc} \toprule  ///
	 "\multicolumn{7}{l}{\textbf{Panel A: School outcomes}} \\" ///
	 "& \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" ///
	 "& \multicolumn{2}{c}{Teacher presence} & \multicolumn{2}{c}{Student attendance} & \multicolumn{2}{c}{Functional facilities} \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	prefoot(\midrule ) ///
	stats(samp N ymeanbef, fmt(a2 %11.2gc a2) ///
	labels("Sample" "N. of obs." "Mean Dep. Var. before")) /// stats to keep
	replace // replace if it exist
	
estout fullmath rdmath fulleng rdeng fullurdu rdurdu /// models
	using "$analysis/tables/causal/TableD2.tex", /// file
	style(tex) /// style of exporting
	starl(* 0.10 ** 0.05 *** 0.01) /// significance stars
	cells(b(star fmt(%6.3f)) se(par fmt(%6.3f))) /// format of cells (coefficient and se)
	mlabels(none) /// no label for models
	collabels(none) /// no label for columns
	keep(1.flagged 1.flagged#1.flag 1.flagged#1.punish 1.flagged#1.afterflag) /// coefficients to keep
	order(1.flagged 1.flagged#1.flag 1.flagged#1.punish 1.flagged#1.afterflag) /// order coefficients
	label interact("$\times$") /// interations
	prehead("\midrule \multicolumn{7}{l}{\textbf{Panel B: Students scores}} \\" ///
	 "& \multicolumn{6}{c}{\underline{Dependent variables (range: 0-100)}} \\" ///
	 "& \multicolumn{2}{c}{Math} & \multicolumn{2}{c}{English} & \multicolumn{2}{c}{Urdu} \\" ///
	" & (1) & (2) & (3) & (4) & (5) & (6) \\" ///
	"\cline{2-7} \addlinespace[0.5em]") ///
	prefoot(\midrule) ///
	postfoot(\bottomrule \end{tabular}) /// this set end to table, note we put it here as we want to append panels
	stats(samp N ymeanbef marfe timefe disfe , fmt(a2 %11.2gc a2 a2 a2 a2) ///
	labels("Sample" "N. of obs." "Mean Dep. Var. before" "\midrule Markaz FE" "Time FE" "District time trends")) /// stats to keep
	topfile("$analysis/tables/causal/1_flagging_outcomes_hist.tex") /// this joins the two panels into a single table
	replace // replace if it exist
	
}

*---------------------------------------------------------------------------------------------------
**# 5. regressions: orange flagging 

**** Figure D5
global treatments tpres satt fac math eng urdu // 
foreach yvar of global treatments{
	
	*main data set
	
	use "$analysis/processed/stacked/cc_stackdata5_`yvar'_orange.dta", clear
	
	local baseper = 4 // define base period
	
	*full regression
	eststo full: reghdfe `yvar' i.flagged##ib(`baseper').time_id [aw = avg_totalreportedteachers_mar], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 

	*threshold sample regression
	eststo rd: reghdfe `yvar' i.flagged##ib(`baseper').time_id if rd1 == 1 [aw = avg_totalreportedteachers_mar], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 
		
	*set graph parameters
	
	// constant
	local xl     = 4
	local yl     = 0
	local flag   = 5
	local punish = 6
	local after  = 9.5
	local typeg  = 1
	
	// changing
	if("`yvar'" == "tpres" | "`yvar'" == "satt" | "`yvar'" == "fac"){
		
		local ymax   = 6
		local ymin   = 8
		local bet    = 2
		local height = 4.2
	
	} 
	else{ // parameters for scores 
	
		local ymax   = 12
		local ymin   = 16
		local bet    = 4
		local height = 8.8
		
	}

	*plot 
	
	eventgraph `yvar' full rd `xl' `yl' `ymin' `ymax' `bet' `height' `flag' `punish' `after' `typeg'
	
	* save graph

	graph export "$analysis/figures/causal/FigureD5_`yvar'.pdf", replace		

}

*---------------------------------------------------------------------------------------------------
**# 6. regressions: tehsil red flagging #

**** Figure D6
global treatments tpres satt fac math eng urdu // 
foreach yvar of global treatments{
	
	*main data set
	
	use "$analysis/processed/stacked/cc_stackdata5_`yvar'_tehsil.dta", clear
	
	local baseper = 4 // define base period
	
	*full regression
	eststo full: reghdfe `yvar' i.flagged##ib(`baseper').time_id [aw = avg_totalreportedteachers_tehsil], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 

	*threshold sample regression
	eststo rd: reghdfe `yvar' i.flagged##ib(`baseper').time_id if rd1 == 1 [aw = avg_totalreportedteachers_tehsil], /// 
		absorb(mar#stack time_id#stack district#stack##c.time_id) vce(cluster mar) 
		
	*set graph parameters
	
	// constant
	local xl     = 4
	local yl     = 0
	local flag   = 5
	local punish = 6
	local after  = 9.5
	local typeg  = 1
	
	// changing
	if("`yvar'" == "tpres" | "`yvar'" == "satt" | "`yvar'" == "fac"){
		
		local ymax   = 6
		local ymin   = 8
		local bet    = 2
		local height = 4.2
	
	} 
	else{ // parameters for scores 
	
		local ymax   = 20
		local ymin   = 16
		local bet    = 4
		local height = 15.8
		
	}

	*plot 
	
	eventgraph `yvar' full rd `xl' `yl' `ymin' `ymax' `bet' `height' `flag' `punish' `after' `typeg'
	
	* save graph

	graph export "$analysis/figures/causal/FigureD6_`yvar'.pdf", replace		

}

*--------------------------------------------------------------------------------------------------- 
**# 7. regressions: alternative difference in differences estimators #

***** Figure D7: sun & abraham (2021): staggered treatment
global treatments tpres satt fac math urdu eng // 
foreach yvar of global treatments{

	* main data: balanced dataset
	use "$analysis/processed/cc_datapacks.dta", clear
	drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)
			
	drop if date_treat <= tm(2011m9)
	/*collapse by markaz: 
		
	note that schools are not constant across markaz, so we need to collapse at the markaz level 
	to cleanly identify the treatment dates 
	*/
		
	collapse (max) treat_`yvar'_  (mean) `yvar' totalteachers, by(mar district date_treat) // estimate markaz level regression due to memory constrains
	replace treat_`yvar'_ = 0 if date_treat <= tm(2012m1)
			
	*variables for DiD
	
	gen flag_date = date_treat if treat_`yvar'_ == 1 // date of flagging
	bysort mar: egen first_flag = min(flag_date) // for each unit, first time flagged
	drop flag_date
	gen relativemonth = date_treat - first_flag // create relative time indicator for each first flag
	gen never_flag = (first_flag == .) // create group of never flagged

	*create time dummies
	
	forvalues k = 4(-1)2 { // create pre period dummies (note -1 used as base)
		gen g_`k' = relativemonth == -`k'
	}
	forvalues k = 0/6{ // create post period dummies
		gen g`k' = relativemonth == `k'
	}

	gen last_flag = (first_flag == 693) // last month of first time flagged

	bys mar date_treat: egen w = mean(totalteachers)

	*full sample estimation of Sun & Abraham
	
	eventstudyinteract `yvar' g_* g0-g6 if first_flag != . & date_treat < 699 , /// periods
		cohort(first_flag) control_cohort(last_flag) /// cohorts
		absorb(i.mar i.date_treat i.district#c.date_treat) /// fixed effects
		vce(cluster mar) // errors
	
	* adjust matrix of coefficients 
	
	matrix C = e(b_iw)
	mata st_matrix("A",sqrt(diagonal(st_matrix("e(V_iw)"))))
	matrix C = C \ A'
	matrix list C

	*additional vector to inlcude base period
	
	matrix g_1 = (0 \ 0)
	matrix C = (C, g_1)
	matrix list C

	*reorder matrix for including 0
	
	matrix D = (C[1,1], C[2,1] \ C[1,2], C[2,2] \ C[1,3], C[2,3] \ C[1,11], C[2,11] \ ///
		C[1,4], C[2,4] \ C[1,5], C[2,5] \ C[1,6], C[2,6] \ C[1,7], C[2,7] \ C[1,8], C[2,8] ///
		\ C[1,9], C[2,9] \ C[1,10], C[2,10])
	matrix list D
	
	*set graph parameters
	
	// constant
	local xl = 4
	local yl = 0
	local flag   = 5
	local punish = 6 
	local after  = 9.5
	
	// changing
	if("`yvar'" == "tpres" | "`yvar'" == "satt" | "`yvar'" == "fac"){
		
		local ymax = 6
		local ymin = 14
		local bet = 2
		local height = 4
	
	} 
	else{ // parameters for scores 
	
		local ymax = 12
		local ymin = 16
		local bet = 4
		local height = 8
		
	}

	* plot
	grstyle init
	grstyle set color "navy"

	coefplot (matrix(D[,1]), se(D[,2]) lcol(navy)), /// coefficients and standard error matrix
			 recast(connect) lw(vthin) /// connected graph
			 baselevels /// include baselevel
			 omitted /// include ommited period (-1)
			 level(95) /// 95% confidence intervals
			 ciopts(recast(rcap)) /// type of confidence intervals
			 vertical /// vertical oriented graph 
			 mcol(navy) /// transparency of points
			 addplot( /// additional graph details to include
				  scatteri `ymax' 4.5 `ymax' 5.49, recast(area) lwidth(none) col(gs14%50) below || ///
				  scatteri -`ymin' 4.5 -`ymin' 5.49, recast(area) lwidth(none) col(gs14%50) below || ///
				  scatteri `ymax' 5.5 `ymax' 6.49, recast(area) lwidth(none) col(gs12%50) below || ///
				  scatteri -`ymin' 5.5 -`ymin' 6.49, recast(area) lwidth(none) col(gs12%50) below || ///
				  scatteri `ymax' 6.5 `ymax' 11.49, recast(area) lwidth(none) col(gs8%50) below || ///
				  scatteri -`ymin' 6.5 -`ymin' 11.49, recast(area) lwidth(none) col(gs8%50) below ///
			) ///
			yline(`yl', lcol("black") lpattern(dash)) /// y line for 0
			xline(`xl', lpattern("dash") lcol("black")) /// x line for initial period
			xlabel(, nogrid) ///
			yscale(r(-`ymin' `ymax')) /// y scale
			ylabel(-`ymin'(`bet')`ymax', nogrid) /// y label
			graphregion(color(white)) /// white background
			xtitle("Relative time", size(large)) /// xtitle
			ytitle("Coefficient (pp)", size(large)) /// ytitle
			title("", size(vsmall) col(black)) /// no title
			text( /// text for each post period
				`height' `flag' "{bf: Flag}" `height' `punish' "{bf:Punish}" `height' `after' "{bf:After}" "{bf:flag}", size(large) ///
					orient(vertical) placement(c) ///
			) ///
			coeflabel( /// label of coefficients
				r1 = "-4" r2 = "-3" r3 = "-2" r4 = "-1" r5 = "0" r6 = "1" r7 = "2" r8 = "3" ///
				r9 = "4"  r10 = "5" r11 = "6" ///
			)			

	* save graph

	graph export "$analysis/figures/causal/FigureD7_`yvar'.pdf", replace		
		
}

***** Figure D8: dechaisemartin & haoulfoullie (2021): treatment on/off
global treatments tpres satt fac math urdu eng // 
foreach yvar of global treatments{
	* main data: balanced dataset
	
	use "$analysis/processed/cc_datapacks.dta", clear
	drop if wing == 3 // we do not consider secondary schools (not subject to monitoring)
	
	*adjust treatment to pre shock
	
	bys mar emis (date_treat): gen treat = treat_`yvar'_[_n+1]
	
	* regression
	bys mar date_treat: egen w = mean(totalteachers)
	
	tempfile estimates_dechais
	
	did_multiplegt_dyn `yvar' mar date_treat treat_`yvar'_, /// basic model
					effects(4) placebo(3)  ///
					trends_nonparam(district) /// linear trends
					weight(w) /// weight by size in terms of teachers 
					cluster(mar) save_results(`estimates_dechais') // cluster var
					
	use `estimates_dechais', clear
		
	local xl     = -0.5
	local yl     = 0
	local flag   = 0
	local punish = 1 
	local after  = 3.2
	
	// changing
	if("`yvar'" == "tpres" | "`yvar'" == "satt" | "`yvar'" == "fac"){
		
		local ymax   = 8
		local ymin   = 10
		local bet    = 2
		local height = 5.5
	}
	else{
		
		local ymax   = 12
		local ymin   = 16
		local bet    = 4
		local height = 8.8
		
	}
	
	twoway (scatteri `ymax' -0.5 `ymax' 0.49, recast(area) lwidth(none) col(gs14%50)) ///
		   (scatteri -`ymin' -0.5 -`ymin' 0.49, recast(area) lwidth(none) col(gs14%50)) ///
		   (scatteri `ymax' 0.5 `ymax' 1.49, recast(area) lwidth(none) col(gs12%50)) ///
		   (scatteri -`ymin' 0.5 -`ymin' 1.49, recast(area) lwidth(none) col(gs12%50)) ///
		   (scatteri `ymax' 1.5 `ymax' 4.49, recast(area) lwidth(none) col(gs8%50)) ///
		   (scatteri -`ymin' 1.5 -`ymin' 4.49, recast(area) lwidth(none) col(gs8%50)) ///
			(connect point_estimate time_to_treat, mcol(navy) lcol(navy) lwidth(vthin) lpattern(solid)) /// coefficient 
		   (rcap up_CI_95 lb_CI_95 time_to_treat, lcol(navy)), /// 
			yline(`yl', lcol("black") lpattern(dash)) /// y line for 0
			xline(`xl', lpattern("dash") lcol("black")) /// x line for initial period
			yscale(r(-`ymin' `ymax')) /// y scale
			ylabel(-`ymin'(`bet')`ymax', nogrid) /// y label
			xlabel(-3(1)4, nogrid) ///
			graphregion(color(white)) /// white background
			xtitle("Relative time", size(large)) /// xtitle
			ytitle("Coefficient (pp)", size(large)) /// ytitle
			title("", size(vsmall) col(black)) /// no title
			text( /// text for each post period
				`height' `flag' "{bf: Flag}" `height' `punish' "{bf:Punish}" `height' `after' "{bf:After}" "{bf:flag}", size(large) ///
					orient(vertical) placement(c) ///
			) ///
		    legend(off)
		
	* save graph

	graph export "$analysis/figures/causal/FigureD8_`yvar'.pdf", replace		

}

